@@ -43,7 +43,7 @@ info_response_schema = {
     },
     'is_running': {
         'required': True,
-        'type': 'bool'
+        'type': 'boolean'
     },
     'arch': {
         'required': True,
@@ -60,6 +60,11 @@ info_response_schema = {
         'type': 'list',
         'nullable': True
     },
+    'prepare_log_file': {
+        'required': True,
+        'type': 'string',
+        'nullable': False
+    },
     'log_file': {
         'required': True,
         'type': 'string',
